# pydiverse.transform

[![CI](https://github.com/pydiverse/pydiverse.transform/actions/workflows/ci.yml/badge.svg)](https://github.com/pydiverse/pydiverse.transform/actions/workflows/ci.yml)

Pipe based dataframe manipulation library that can also transform data on SQL databases

## Installation

To install the package locally in development mode, you first have to install
[Poetry](https://python-poetry.org/docs/#installation).
After that, install pydiverse transform like this:

```bash
git clone https://github.com/pydiverse/pydiverse.transform.git
cd pydiverse.transform

# Create the environment, activate it and install the pre-commit hooks
poetry install
poetry shell
pre-commit install
```
